PyObserver
==========

.. currentmodule:: cysgp4

.. autoclass:: PyObserver
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PyObserver.loc

   .. rubric:: Attributes Documentation

   .. autoattribute:: loc
